package cn.org.spring.wechar.controller;

import cn.hutool.core.date.DateTime;
import cn.hutool.core.date.DateUtil;
import cn.org.spring.common.util.StringUtil;
import cn.org.spring.wechar.bean.Result;
import cn.org.spring.wechar.utils.CacheUtil;
import cn.org.spring.wechar.utils.PrizeRandomUtil;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.CookieValue;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.Date;
import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.TimeUnit;

/**
 * @author： 谢辉
 * @date： 2021/5/18
 * @email: xieh_mail@163.com
 * @description： 抽奖
 * @modifiedBy：
 * @version: 1.0
 */
@RestController
@RequestMapping("/v1/prize")
public class PrizeController {

    @Autowired
    CacheUtil cacheUtil;

    // String 可以为任意类型 也可以自定义类型
    static Map<String, Integer> keyChanceMap = new HashMap<String, Integer>();

    static {
        //key值的是奖品名称或者id。value为中奖的概率
        keyChanceMap.put("0", 10);// 谢谢惠顾
        keyChanceMap.put("1", 200);// 中1元
        keyChanceMap.put("3", 500);// 中3元
        keyChanceMap.put("4", 3000);// 中4元
    }

    /**
     * 话费抽奖
     *
     * @return
     */
    @GetMapping("/getTelCharge")
    public Result getTelCharge(@CookieValue(value = "wechat-token") String userId) {
        if (StringUtils.isEmpty(userId)) {
            return Result.fail("获取用户信息失败");
        }
        Boolean exists = cacheUtil.exists("lottery:" + userId);
        if (exists) {
            return Result.fail("一天只能抽取一次，请您明天再来~~~");
        } else {
            String result = PrizeRandomUtil.chanceSelect(keyChanceMap);
            if (StringUtil.isEmpty(result)) {
                result = "0";
            }
            long currentTime = System.currentTimeMillis();
            long diff = timeDiff(currentTime);
            if (diff > 0) {
                cacheUtil.set("lottery:" + userId, result + ":" + currentTime, diff, TimeUnit.MILLISECONDS);
            }
            return Result.ok(result);
        }
    }


    /**
     * 获取当前时间和当天结束的时间差
     *
     * @param currentTimeMillis 单位毫秒
     * @return 时间差
     */
    private long timeDiff(long currentTimeMillis) {
        DateTime dateTime = DateUtil.endOfDay(new Date());
        long endDayOfMillis = dateTime.getTime();
        return (endDayOfMillis - currentTimeMillis);
    }
}
